@@ -360,20 +360,23 @@ def _cmd_help(arg_obj: Args) -> str:
 
     - mtdstr: String name of the method (ie: 'getOrganizations')
     """
-    result = arg_obj.method.__doc__  # Start with the doc string
+    result = ''  # Start with an empty result
+    #  Iterate the docstring lines
+    for line in arg_obj.method.__doc__.splitlines():
+        result += f'\n{line.lstrip()}'  # And strip the leading whitespace
     # Set the docstring header (wrapped in asterisks) to uppercase
     result = re.sub(r'\*\*(.*)\*\*', lambda ele: ele.group(0).upper(), result)
-    # Remove leading tabs from header and add en extra line break
-    result = re.sub(r'\t\t\*\*(.*)\*\*', r'\1\n', result)
-    # Remove leading tabs from link
-    result = re.sub(r'\t\t(https://.*)\n', r'\1', result)
+    # Remove leading whitespace from header
+    result = re.sub(r'[\s]+\*\*(.*)\*\*', r'\1', result)
+    # Remove leading whitespace from link and space it below the header
+    result = re.sub(r'[\s]+(https://.*)\n', r'\n\n\1', result)
     if arg_obj.positionals:  # If there are positional (required) arguments
         # Add an "All Arguments" line below http for the argument entries
         result = re.sub(r'(https://.*)\n', r'\1\n\nAll Arguments:\n', result)
     # Remove leading tabs from argument entries and append double-hypen
-    result = re.sub(r'\t\t- ([a-zA-Z0-9_]+) ', r'  --\1 ', result)
+    result = re.sub(r'- ([a-zA-Z0-9_]+) ', r'  --\1 ', result)
     # Add the signature at the bottom of the help.
-    result += '\nFunction Signature:\n\t'\
+    result += '\nFunction Signature:\n  '\
               f'>>> def {arg_obj.name}{arg_obj.signature}:'
     return result
 
@@ -650,6 +653,8 @@ def _object_filter(listofdicts: list, filter_strs: list,
     if type(listofdicts) is not list:
         log.error(f'Cannot filter non-list. Returning data: {listofdicts}')
         return listofdicts
+    if not listofdicts:  # If list is empty
+        return listofdicts  # Return it back since it can't be filtered
     filters = []  # Build list of dicts for filter definitions.
     for filter_str in filter_strs:  # Iterate user provided strings to parse
         # Extract the key name up to the colon
@@ -765,6 +770,47 @@ def _column_filter(listofdicts: list, columns_str: str) -> []:
     return result
 
 
+def _normalize_listofdicts(listofdicts: list) -> []:
+    """
+    Prepare a list of dicts for tabulation by normalizing the dicts: make
+        sure each dict in the list has the same keys present. This will turn:
+        [{'key1': 'val1'}, {'key2': 'val2'}]
+        into:
+        [{'key1': 'val1', 'key2': ''}, {'key1': '', 'key2': 'val2'}]
+        which will allow proper tabulation to happen.
+
+    - listofdicts: List of dict objects. Posibly where the dicts do not have
+        the samek set of keys Example:
+        [{'id': '1', 'name': 'THING1'}, {'id': '2', 'name': 'THING2'}]
+    """
+    if not listofdicts:  # If it's empty or None
+        log.info('Input is empty or None. Returning it.')
+        return listofdicts  # Don't modify it, just return it
+    if type(listofdicts) is not list:  # If it's not a list
+        log.info('Input is not a list. Returning it.')
+        return listofdicts
+    if type(listofdicts[0]) is not dict:  # If the list doesn't contain dicts
+        log.info('Input\'s first entry is not a dict. Returning list.')
+        return listofdicts
+    keylist = []  # List of all keys which appear across all dicts
+    for d in listofdicts:  # For each dict in this list
+        for key in d:  # For each key in this dict
+            # Add the key to the list if not there already
+            if key not in keylist:
+                keylist.append(key)
+    result = []  # Result list of dicts to be output
+    for d in listofdicts:  # Iterate the original list of dicts
+        # Start the new dict which will be added to the result list
+        newdict = {}
+        for key in keylist:  # Iterate the full list of keys
+            if key in d:  # If this key is already in the source dict
+                newdict[key] = d[key]  # Then add the key and value
+            else:  # If this key is not already in the source dict
+                newdict[key] = ''  # Then add an empty value
+        result.append(newdict)  # Add the replacement dict to the result list
+    return result
+
+
 def _nice_table(listofdicts: list) -> None:
     """
     Print out a nicely formatted table from a list of dicts.
@@ -779,10 +825,11 @@ def _nice_table(listofdicts: list) -> None:
     console = Console()  # Instantiate the Rich console
     # Instantiate the table object with header settings
     table = Table(show_header=True, header_style="bold magenta")
+    normalizedlist = _normalize_listofdicts(listofdicts)
     # For each header column name in the first dict in the list
-    for head in listofdicts[0]:
+    for head in normalizedlist[0]:
         table.add_column(head)  # Add that header column name
-    for d in listofdicts:
+    for d in normalizedlist:
         # Add the dict values as args to table.add_row
         table.add_row(*list(d.values()))
     console.print(table)  # Print out the table
@@ -1102,6 +1149,9 @@ def main(argstring=None) -> None:
             else:  # If we are in front of a pipe
                 # Log the exception but don't exit the program
                 _log_exception(e)
+                # Set empty result so we don't reuse previous result or
+                #     error out
+                result = []
         log.debug(f'Target method result: \n{json.dumps(result, indent=4)}')
         if args.filters:  # If we are supposed to filter result objects
             # Run the results through the filter
